@@ -24,7 +24,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "giggle-revision.h"
+#include "libgiggle/giggle-revision.h"
 
 G_BEGIN_DECLS
 
@@ -54,7 +54,10 @@ void               giggle_diff_tree_view_set_revisions     (GiggleDiffTreeView *
 							    GiggleRevision     *from,
 							    GiggleRevision     *to);
 
-gchar *            giggle_diff_tree_view_get_selection     (GiggleDiffTreeView *view);
+char *             giggle_diff_tree_view_get_selection     (GiggleDiffTreeView *view);
+
+char *             giggle_diff_tree_view_get_filename      (GiggleDiffTreeView *view,
+							    GtkTreePath        *path);
 
 G_END_DECLS
 
